Monty Python's Flying Circus: Just the Words - Episode 43

# Episode Forty-three: Hamlet

Bogus psychiatrists
'Nationwide'
Police helmets
Father-in-law
Hamlet and Ophelia
Boxing match aftermath
Boxing commentary
Piston engine (a bargain)
A room in Polonius's house
Dentists
Live from Epsom
Queen Victoria Handicap

Colour code: Michael Palin - Eric Idle - Graham Chapman - Terry Jones - Terry Gilliam - Carol Cleveland

| Tragic music in background.
| CAPTION: 'HAMLET' CAPTION: 'BY WILLIAM SHAKESPEARE' CAPTION: 'ACT ONE'
| Quick cut to a close shot of a big American car skidding round a corner. Music. Montage of close ups of tires, foot on accelerator shots, etc. with a deafening sound track. The car skids to a halt at the side of the curb. Pull out to reveal it is in a smart Harley Street type location. The door opens and out gets a man in black leotard, with make-up and a small crown - Hamlet, in fact. He goes into a doorway, presses the doorbell and waits. Cut to modern psychiatrist's office. Hamlet is lying on the couch.
Hamlet | It's just that everywhere I go it's the same old thing. All anyone wants me to say is 'To be or not to be ...'
Psychiatrist | '... that is the question. Whether 'tis nobler in the mind to suffer the slings and arrows of outrageous ...'
Hamlet | (quickly) Yes, it's either that, or 'Oh that this too solid flesh would melt ...'
Psychiatrist | (taking over) '... would melt, thaw and resolve itself into a dew. Or that the everlasting had not fixed his canon 'gainst self slaughter ...'
Hamlet | Yes. All that sort of thing. And I'm just getting really fed up.
Psychiatrist | (picking up a skull) Now do the bit about 'Alas poor Yorick ...'
Hamlet | No. I'm sick of it! I want to do something else. I want to make something of my life.
Psychiatrist | No. I don't know that bit.
Hamlet | I want to get away from all that. Be different.
Psychiatrist | Well um ... what do you want to be?
Hamlet | A private dick!
Psychiatrist | A private dick?
Hamlet | Yes, a private dick!
Psychiatrist | Why do you want to be a private dick?
Hamlet | Ooh ... why does anyone want to be a private dick? Fame, money, glamour, excitement, sex!
Psychiatrist | Ah! It's the sex, is it?
Hamlet | Well, that's one of the things, yes.
Psychiatrist | Yes, what's the sex problem?
Hamlet | Well, there's no problem.
Psychiatrist | Now, come on, come on. You've got the girl on the bed and she's all ready for it.
Hamlet | No, no, it's nothing to do with that.
Psychiatrist | (getting excited) Now come on, come on, there she is, she's all ready for it. She's a real stunner, she's got great big tits, she's really well stacked and you've got her legs up against the mantelpiece.
Dr Natal | All right, Mr Butler, I'll take over. (a distinguished-looking man in a suit enters; the psychiatrist leaves) Morning, Mr Hamlet. My name's Natal. Sorry to keep you waiting. Now what seems to be the problem?
Hamlet | Well, I was telling the other psychiatrist ...
Dr Natal | He's ... he's not a psychiatrist.
Hamlet | Oh. He said he was a psychiatrist.
Dr Natal | Well ... yes ... um, he's a kind of psychiatrist he's ... he's not a proper psychiatrist. He's not er ... fully qualified ... in, um, quite the sort of way we should want. Anyway the problem I believe is basically sexual is it?
| The psychiatrist puts his head round door.
Psychiatrist | I asked him that!
Dr Natal | Get out! (the psychiatrist goes; to Hamlet) Now then, you've got the girl on the bed. You've been having a bit of a feel up during the evening. You've got your tongue down her throat. She's got both her legs up on the mantelpiece ...
| Enter a distinguished-looking psychiatrist in a white coat.
Third Psychiatrist | (Michael, quietly and authoritatively, indicating the door) Dr Natal ... out please!
Dr Natal | I'm talking to a patient! Oh ... (he goes)
Third Psychiatrist | Out please! I'm terribly sorry, sir. We have a lot of problems here with bogus psychiatrists. One of the risks in psychiatry I'm afraid. Unfortunately they do tend to frighten the patient and they can cause real and permanent damage to the treatment. But I assure you that I am a completely bona fide psychiatrist. Here's my diploma in psychiatry from the University of Oxford. This here shows that I'm a member of the British Psychiatric Association, a very important body indeed. Here's a letter from another psychiatrist in which he mentions that I'm a psychiatrist. This is my Psychiatric Club tie, and as you can see the cufflinks match. I've got a copy of 'Psychiatry Today' in my bag, which I think is pretty convincing. And a letter here from my mother in which she asks how the psychiatry is going, and I think you'll realize that the one person you can't fool is your mother. So if you'd like to ask me any questions about psychiatry, I bet I can answer them.
Hamlet | No, no, it's all right, really.
Third Psychiatrist | OK, you've got this girl on your bed, you've had a few drinks, you've got her stretched out and her feet on the mantelpiece ... (the intercom buzzes) yes, what is it?
Intercom Voice | There's a proper psychiatrist to see you, Dr Rufus Berg.
Third Psychiatrist | Oh, oh my God! Ok, thank you. (he hurriedly changes into a police constable's uniform) Right, thank you very much for answering the questions, sir. We'll try not to trouble you again, sir. (exits hurriedly)
| A fourth psychiatrist rushes in.
Fourth Psychiatrist | Right you've got the girl down on the bed, you've got her legs up on the mantelpiece.
| Two men in white coats bundle him out. Dr Natal Enters.
Dr Natal | Well, well done, Mr Hamlet. You've done extremely well in our disorientation tests.
Hamlet | Oh? Oh!
Dr Natal | You see, I'm sorry it might have confused you a little, but we do this to try to establish a very good doctor/patient relationship, you see ... we do it to sort of, as it were, to break down the barriers. All right?
Hamlet | Yes fine.
Dr Natal | Good! Well, you've got her legs up on the mantelpiece ...
| The two men come in and chase him out. Cut to a man at a consultant's desk in a smart West End surgery.
| CAPTION: 'DR BRUCE GENUINE, CHAIRMAN OF THE PSYCHIATRIC ASSOCIATION'
Dr Bruce | On behalf of the Psychiatric Association, I should like to say that we are taking firm action to clamp down on the activities of bogus psychiatrists. In fact in many areas of modern psychiatry computers are now being increasingly used for the first basic diagnosis and this has gone a long way in eliminating the danger of unqualified impostors.
| Cut to Hamlet in an office. A big, impressive-looking computer beside him.
Computer | (in tinny computer voice) You've had your tongue down her throat and she's got her legs on the mantelpiece.
| The door opens and a nurse appears.
Nurse | Out!
| The computer scuttles for the door, revealing that underneath it are six pairs of legs, in pin-striped trousers and expensive shoes. Cut to the same computer in a field. The nurse picks up a bazooka. The computer rises into the air, the nurse fires at it and it explodes. 'Nationwide' type music and credits. Michael Charlton in a studio.
Charlton | Good evening and welcome to 'Nationwide'. The programme where we do rather wet things nationally and also give you the chance to see some rather wet items in the Regions. Well, everyone is talking about the Third World War which broke out this morning. But here on 'Nationwide' we're going to get away from that a bit and look instead at the latest theory that sitting down regularly in a comfortable chair can rest your legs. It sounds very nice doesn't it, but can it be done? Is it possible or practical for many of us in our jobs and with the sort of busy lives we lead to sit down in a comfortable chair just when we want? We sent our reporter John Dull to find out.
| Cut to Dull sitting in a chair on Westminster Bridge.
Reporter | Well, here I am on London's busy Westminster Bridge, seeing just how much time sitting down can take. Well, I arrived here by train at about 8:50, it's now 9:05, so I've been here approximately twelve minutes and if it's any encouragement, I must say that my legs do feel rested.
| A policeman walks up to him.
Policeman | Is this your chair?
Reporter | Er ... well, no, it's a prop.
Policeman | It's been stolen!
Reporter | What?
Policeman | This belongs to a Mrs Edgeworth of Pinner - she's standing over there.
| Cut to worried middle-aged lady, standing on the other side of the road, peering across. She has an identical chair in one hand.
Reporter | Ah well, it's nothing to do with me. It's just a prop which the BBC ... aaargh!
| The policeman pushes the reporter off and picks up the chair.
Policeman | It's got her name on the bottom. (he indicates: Mrs E. Edgeworth)
Reporter | Well er ... perhaps you'd better give it back to her.
Policeman | You don't believe I'm a policeman, do you?
Reporter | Yes I do!
Policeman | What am I wearing on my head?
Reporter | A helmet
Policeman | (correcting him) A policeman's helmet!
Reporter | Yes.
Policeman | (taking off his helmet and demonstrating) You see that?
Reporter | Yes.
Policeman | That little number there?
Reporter | Yes.
Policeman | That is a Metropolitan Area Identification Code. No helmet is authentic without that number.
Reporter | I see.
Policeman | Kids helmets, helmets you get in toy shops, helmets you buy at Christmas. None of them is authentic ... Hang on. (he turns and crosses the busy road)
Reporter | Oh could I ...
Policeman | Hang on!
| He goes across to Mrs Edgeworth, and tries to grab the other chair from her. Mrs Edgeworth resists. He clouts her and pulls the chair away. He brings it back across the road and sits down next to the reporter.
Policeman | Mind you I didn't join the police force just to wear the helmets you know. That just happens to be one of the little perks. There are plenty of jobs where I could have worn a helmet, but not such a nice helmet. (Mrs Edgeworth is gesticulating; another policeman comes up and drags her away) This helmet, I think, beats even some of the more elaborate helmets worn by the Tsar's private army, the so-called Axi red warriors. You know about them?
Reporter | Well, no I don't.
Policeman | Ah! Their helmets used to look like ... you got any paper?
Reporter | Well only these scripts.
| The policeman gets up, looks up the street, and selects a businessman with a briefcase, who is hurrying away from him. The policeman runs up to him, grabs his arm, twists it up behind his back and wrenches the briefcase from his hand. He opens it, gets out some paper, then drops briefcase before the amazed owner, and ambles back to his chair, neatly grabbing a pen from a passer-by's inside pocket.
Policeman | I'll have that!
Man | I say!
| The policeman sits down again and starts to draw, talking the while.
Policeman | Now then. Their helmet was not unlike the bobby's helmet in basic shape. It had an emblem here, and three gold - and in those days it really was gold, that's part of the reason the Tsar was so unpopular - three gold bands surmounted by a golden eagle on the apex here. Pretty nice helmet, eh?
Reporter | Yes.
Policeman | I think the domed helmet wins every time over the flattened job, you know, even when they're three cornered ... (suddenly his eyes light on two office secretaries opening their packed lunch on a nearby seat) ... you want something to eat?
Reporter | (sensing what's going to happen, hurriedly) Well no, er really ...
Policeman | (approaching the girls and getting out his notebook) Hang on. You can't park here you know.
Women | (bewildered) We're not parked!
Policeman | No parked! What's that then?
Women | That's our lunch.
Policeman | Right. I'm taking that in for forensic examination.
Women | Why?
Policeman | Because it might have been used as a murder weapon, that's why! (the girls look at each other; the policeman grabs their lunch) Yeah, not bad. Could be worse. (to the reporter) Beer?
Reporter | (desperately) No, no, please ... honestly ... please ...
| The policeman walks off. There is a crash of breaking glass. An alarm bell starts to ring. The reporter winces. The policeman walks into shot again, holding two bottles of beer. He sits down, opens the beers with his teeth and hands one to reporter who is very embarrassed.
Policeman | Now, the Chaldeans, who used to inhabit the area in between the Tigris and Euphrates rivers, their helmets were of the modular restrained kind of type ...
| To lyrical music the camera pans across the road, and comes across a couple making love on the pavement. Pedestrians step over them.
Carol | Oh Robert, tell me I'm beautiful.
Robert | Oh you are, you are!
Carol | Oh Robert, do you mean that?
Robert | Of course I do.
Carol | You're not just saying that because I asked you?
Robert | Of course not.
Carol | Oh Robert ... Robert, are you sure it doesn't put you off?
Robert | What?
Carol | My father wanting to come and live with us.
Robert | No, of course I don't mind your father coming to live with us.
Carol | He wouldn't just be living with us.
Robert | What do you mean?
Carol | Well, he finds it very difficult to get to sleep on his own, so I said he could sleep with us.
Robert | He wants to put his bed in our room?
Carol | No, no, of course not.
Robert | Oh good ...
Carol | Our bed is plenty big enough for three ...
Robert | What?
Carol | He'd just get into bed and go to sleep.
Robert | No. I'm not having that.
Carol | Oh Robert, I thought you loved me?
Robert | Well I do, but ...
Carol | Well, he wouldn't look.
Robert | He's bound to peek.
Carol | No, no, he wouldn't honestly.
Robert | No! No! No!!
| Cut to the three of them in bed. Robert is in the middle. Father wears striped pyjamas, the others are nude. There is an uncomfortable silence.
Father | You young couple just carry on. Take no notice of me ... (silence; they smile half-heartedly) I don't want to feel as though I'm getting in the way.
Carol | Oh no dad, you're not.
Robert | No, no.
Father | Good.
| Silence again.
Carol | Well, I think I'll get to sleep.
Father | Are you sure?
Carol | Oh yes, I'm a bit tired after the wedding.
Father | Bob, what about you?
Robert | Oh yes, all right, yes.
Father | Oh well, I seem to be O/C lights.
Carol | (to Robert) Good night, darling.
Robert | Good night.
Father | Good night!
| He switches the light off. It is pitch dark. There is a long pause, then a strange scraping noise like a pencil being sharpened. The scraping is followed by sawing and is eventually replaced by short sharpknocking sounds. This goes on for some time.
Carol | Father. Father, what are you doing?
Father | I'm making a boat.
Carol | What?
Father | It's the Cutty Sark. It's a model I've been making in the dark for some years now.
Carol | Well, wouldn't it be better with the light on?
Father | No, no, I'm making it in the dark, that's the point.
| There is a click. The light goes on. He looks disappointed. In his hands is a completely shapeless mass of wood and nails.
Father | Oh dear, not as accurate as I thought.
Robert | It's not the Cutty Sark!
Father | Well it hasn't got its sails yet. Oh well I'll ... I'll have a look at it in the dark room in the morning. Good night. (grunts from the others who are already snuggling down; lights go off; silence)
| Animated opening titles. Banging on the wall from next door.
Man | Shut up! Will you shut up in there!
| Cut to a middle-aged man with small moustache and neat pyjamas banging on the wall with what appears to be an Indian club.
Man | Shut up! (It goes quiet next door) That's better.
| He walks to a side wall and hangs his club on a hook beneath big old-fashioned art-nouveau sign clearly labelled `The Burlington Wall-banger'. He goes across to bed and gets in. In the bed are a party of four Japanese businessmen in suits with lapel badges, two lady American tourists with rain hats and cameras, three other moustached English gentlemen in pyjamas, four Tour De France riders, three Swedish businessmen, and Winston Churchill. In the corner of the room are three Tour De France bicycles. All the people ae watching TV. All in the bed are slightly tear-stained and sad, and eating popcorn and crisps, utterly absorbed. On TV we hear a Hamlet sad speech.
Hamlet | I am myself indifferent honest, but then I could accuse me of such things that it were better my mother had not borne me.
| Cut to the TV set in the room. Close in on TV set to see Hamlet lying beside Ophelia, who is gazing at him intently. It is the same Hamlet we saw in the psychiatrist's scene. They are in one of those rather austere modern theatre sets.
Hamlet | O fair Ophelia, nymph, in thy orisons, be all my sins remembered ...
Ophelia (Connie Booth) | So anyway, you've got the girl on the bed and her legs are on the mantelpiece ...
| The nurse from the psychiatrist's office enters.
Nurse | Out! (bundles her off)
| ANIMATION: Ends with a poster 'Boxing Tonite! The Killer vs. The Champ. 15 Rounds'. Cut to a dressing room at Madison Square Gardens, table, chairs, towels, and the usual paraphernalia. Noise of a crowd outside. The door opens and in comes Mr Gabriello, and two assistants carrying a boxer on a stretcher. Smoke, action, excitement come in with them.
Mr Gabriello | That was a great fight, Champ, a great fight, you hear! Oh boy, what a fight, Champ, what a great fight! You nearly had him, Champ, you nearly had him ... where's his head?
First Assistant | I got it in here, Mr Gabriello.
| He holds up a carrier bag. Gabriello goes over to it, looks inside and shouts into it.
Mr Gabriello | You were great, Champ, d'you hear, you were great!
First Assistant | (looking in the bag) He's got a nasty cut over his eye.
Mr Gabriello | Yeah, I think it was a mistake him wearing spectacles. (gives the bag to the assistant) Oh well, get that sewn onto his body in time for the press pictures.
First Assistant | OK, Mr Gabriello.
Mr Gabriello | (to second assistant) Wasn't he great my boy?
Second Assistant | (Eric) He was great, Mr Gabriello.
Mr Gabriello | The way he kept fighting after his head came off!
Second Assistant | He was better when the head came off, Mr Gabriello. He was really dodging the guy.
Mr Gabriello | Yeah, I reckon that if he could've lasted till the end of that first minute, he would've had the Killer worried.
Second Assistant | Sure, Mr Gabriello.
Mr Gabriello | Oh he was great. Did you see his left arm?
Second Assistant | No!
Mr Gabriello | OK, we'll look around the hall after everybody's gone.
Second Assistant | Do you realize Mr Gabriello, some of those guys out there paid over $2,000 for a ringside seat.
Mr Gabriello | And where did the head land? Right at the back, that's justice... (the door opens; a black cleaner comes in) What d'you want?
| The cleaner holds up a carrier bag.
Black Man | This your boy's head?
Mr Gabriello | No, no, we've got his head. He ain't hurt that bad.
Second Assistant | (looking in the bag) Hey, that's Gerry Marinello. He fought the Killer last week.
Mr Gabriello | OK, give it to me. I'm seeing his trainer tomorrow. I'll give it to him.
| The cleaner is ushered out.
Second Assistant | Hey, Mr Gabriello. The press is still outside. Are you ready for them?
Mr Gabriello | How's the Champ?
First Assistant | (working away with needle and thread) Well, the head's on OK. But there's still a left arm missing.
Mr Gabriello | OK, well keep the dressing gown kinda loose, OK. (Gabriello goes to door and opens it) OK boys, come on in!
| The press surge in. The fighter is propped up.
First Reporter | Hey Mr Gabriello, Mr Gabriello. Did you expect your boy to last the full twenty-eight seconds?
Mr Gabriello | This boy has never let me down. He's the pluckiest goddamn fighter I've ever trained.
Second Reporter | Were you worried when his head started to come loose?
Mr Gabriello | No, no, we were expecting that. I told them to expect it to and it did. He ain't stupid.
First Reporter | Hey, can we have a word with the Champ?
Mr Gabriello | Yeah OK. But keep the questions simple.
First Reporter | Hey Champ! How're you feeling?
Mr Gabriello | (angrily) I said keep the questions simple!
Second Reporter | Mr Gabriello. People are saying that the kid ought to be buried. His head's come off in the last six fights.
Mr Gabriello | There's no question of burying the kid. He's just reaching the top.
Second Reporter | Well, shouldn't he just stay in hospital?
Mr Gabriello | No, he ain't going to no hospital. He's got the return fight next week.
| Shot of the 'New York Times' headline 'Champ to be kept alive for big return'. Cut to a hospital ward. Numerous doctors and nurses are listening to the radio.
Radio Voice | And there's Frank Sinatra leaving the ring. Behind him is George Raft, another great boxing fan, Martin Bormann, acknowledging the applause, and with him of course is Gus Himmler, who did an awful lot for the sport in his country in the early 1940s. And here comes the Champ now and he seems in good shape to meet the Killer once again. Before an audience, some of them will have paid $920,000 million for the privilege of seeing this boy get beaten up. And there's the bell.
Patient | (Having a heart attack on the bed in the corner) Aaarghhh!
All | Quiet!!
Radio Voice | And a left and a right and a right jab that's taken the Champ's shoulder off. And here's the Killer again with a right and another left and a bash with a hammer and a terrific smack with a heavy thud right into the skull and there's a gaping hole right through the Champ's body now. And now the Killer's working on the cut eye with a series of beautifully placed punches and the head's coming loose. (the doctors and nurses getting increasingly excited) The Champ must try and keep his head on. The Killer's kicked him in the groin and he's bitten half his left buttock off and the referee's stepped in with a warning there. What a plucky fighter this Champ is. He's fighting as well as I've ever seen him. Must be losing blood at a rate of a pint a second now. It's everywhere. Certainly those who paid one and a half million dollars for those ringside seats are really getting their money's worth. They're covered in it. And his head's off! (everyone cheers) His head that's come off in so many fights is off in the thirty-first second. It's rolled away down to the left ... but what's happening? The Killer's being talked to by the referee. There's the Champ ... plucky little body racing around the ring, trying to find his opponent. And the Killer has been disqualified. (pandemonium breaks out in the ward - some patients cheering, doctors thumping them in disagreement) He's been disqualfied ... this great fighter who has killed more than twenty people in his career has at last been defeated by this courageous headless little southpaw from New York. And there's a great roar here as the referee raises the arm of the new World Heavyweight Champion. What a pity the rest of his body wasn't there to see it. (general disappointment; someone changes channels)
Second Radio Voice | Well here in London it's 12:30 and time for 'The Robinsons'. (everyone perks up) An everyday story of bla-di-bl-di-bla ... (sings 'Archers' theme tune) da di da di da di da ... and so on.
Mrs Non-Robinson | (on radio) Morning Mrs Robinson.
Mrs Robinson | (on radio) Morning Mrs Non-Robinson.
Mrs Non-Robinson | Been shopping?
Mrs Robinson | No, ... I've been shopping.
| During this exchange there have been six cuts to close-ups of radios of different shapes and sizes.
Mrs Non-Robinson | What'd you buy?
| Pull out to reveal a pepperpot. Mrs Non-Gorilla sitting beside a radio on a park bench.
Mrs Robinson | (on radio) A piston engine.
Mrs Non-Robinson | What d'you buy that for?
Mrs Robinson | It was a bargain.
Mrs Non-Gorilla | Bloody rubbish. (she turns the radio off)
| Quick cut to a hospital, doctor on a bed listening to a radio. It switches off.
Doctor | I wanted to listen to that!
| Cut back to Mrs Non-Gorilla. Another pepperpot approaches.
Mrs Non-Gorilla | Morning Mrs Gorilla.
Mrs Gorilla | Morning Mrs Non-Gorilla.
Mrs Non-Gorilla | Have you been shopping?
Mrs Gorilla | No ... been shopping.
Mrs Non-Gorilla | Did you buy anything?
Mrs Gorilla | A piston engine!
| She reveals a six-cylinder car engine on a white tray, on a trolley.
Mrs Non-Gorilla | What d'you buy that for?
Mrs Gorilla | Oooh! It was a bargain.
| Start to pan away from them, their voices become fainter.
Mrs Non-Gorilla | Oooohhh!
| Pan across a civic park, of which the only occupants are about ten pepperpots, dressed identically, scattered across on benches. One pepperpot is in a wheelchair. We come in to Mrs Non-Smoker, unwrapping a parcel and calling to the birds.
Mrs Non-Smoker | Come on little birdies ... come on little birdies ... tweet tweet ... come and see what mummy's got for you ...
| She unwraps the parcel revealing a leg of lamb which she hurls at the gathered birds. A screech. She kills a pigeon. She reaches in a another bag and produces two tins of pineapple chunks and throws them.
Mrs Non-Smoker | Come on little birdies ... tweety tweety ... oooh look at this ... tweet tweet ... ooohhh nice one ... come on little birdies ...
| She chortles with delight as she hurls a huge jar of mayonnaise which smashes messily. She then throws a large frozen turkey, a jar of onions, a bag of frozen peas, and a bottle of wine. We widen as Mrs Smoker, with an identical piston engine to the last pepperpot, comes up to Mrs Non-Smoker. Quite a large area in front of Mrs Non-Smoker is littered with packaged foods and dead birds; a bird is pecking at a tin of pate; a small pond in front of her has a swan upside down with its feet sticking in the air, a huge tin floating beside it.
Mrs Non-Smoker | Oohh hello, Mrs Smoker.
Mrs Smoker | Hello Mrs Non-Smoker.
Mrs Non-Smoker | What, you been shopping then?
Mrs Smoker | Nope ... I've been shopping!
Mrs Non-Smoker | What d'you buy?
Mrs Smoker | A piston engine!
Mrs Non-Smoker | What d'you buy that for?
Mrs Smoker | It was a bargain!
Mrs Non-Smoker | How much d'you want for it?
Mrs Smoker | Three quid!
Mrs Non-Smoker | Done. (she hands over the money)
Mrs Smoker | Right. Thank you.
Mrs Non-Smoker | How d'you cook it?
Mrs Smoker | You don't cook it.
Mrs Non-Smoker | You can't eat that raw!
Mrs Smoker | Ooooh ... never thought of that. Oh, day and night, but this is wondrous strange ...
Mrs Non-Smoker | ... and therefore is a stranger welcome it. There are more things in Heaven and Earth Horatio, than are dreamt of in your philosophy. But come, the time is out of joint. Oh cursed spite, that ever I was born to set it right. Let's go together.
| They get up and go. Fade to black. CAPTION: 'ACT TWO - A ROOM IN POLONIUS'S HOUSE' Cut to a Frank Bough type presenter. Behind him are sports pictures.
Presenter | Hello, and welcome to 'A Room in Polonius's House'. Well tonight is European Cup night. One result is already in from Munich. The European Cup, first round, second leg, Bayern München 4397, Wrexham 1. So Wrexham going through there on aggregate. Well, now it's time for racing, so let's go straight over to Epsom and Brian McNutty.
| Cut to dentist's surgery. A dentist is filling a patient. He talks to camera.
| SUPERIMPOSED CAPTION: 'LIVE FROM EPSOM'
Dentist | Well over here at Epsom, there are chances a-plenty for those who want to make a good start in...
Patient | Dentistry.
Dentist | Dentistry. It's a well-off suburb, so most people have their own teeth and surgeries are opening at a rate of four or five a week.
| Cut to a housewife in a back garden standing in front of a washing line with really nasty stained washing on it: some man's trousers with very nasty stain on crotch and running down the leg, a badly torn sheet with melted chocolate bisquit stuck on it, a huge bra, with cups eighteen inches across, two pieces of streaky bacon and a fried egg pegged on the line, and more dirty washing. CAPTION: 'LIVE FROM EPSOM'
Housewife | Well, it's only forty-four minutes from the West End on the train and it's not too built up, so you can have a nice garden. And the people of Epsom are a very nice class of person.
| Cut to a property developer in a main street. CAPTION: 'LIVE FROM EPSOM'
Property Dealer | Well here in High Street Epsom, There are ample opportunities for all kinds of redevelopment. As you can see, (he indicates old houses) behind me now there are a high level of low density consumer units, still not fully maximizing site value. This could be radically improved by a carefully planned programme of demolition. And of course most of the occupants ere...er...elderly folks, so they wouldn't put up much of a fight.
| Cut to Epsom racecourse, and a presenter, Brian McThighbone, up against the paddock rail. CAPTION: 'LIVE FROM EPSOM'
Brian | Good afternoon. Well in fact there's still a few minutes to go before the main race on the card this afternoon - the Queen Victoria Handicap. So let's have a quick word with the winner of the last race, one of the season's top jockeys - Ronnie Mau-Mau. (a jockey's cap comes into shot, which is all we ever see of him) Good afternoon, Ronnie.
First Jockey | Good afternoon, Brian.
Brian | (pointing his stick-mike down) A very fine ride there, Ronnie.
First Jockey | Well, a fine horse, Brian. You know you can't go wrong.
Brian | Do you fancy your chances for the Derby?
First Jockey | (vigorously nodding) Oh very definitely, very definitely, indeed, certainly Brian.
Brian | Well, let's just see if a colleague of yours agrees with that. Let's just have a quick word with Desmond Willet. Afternoon Des.
| Another different silk hat comes into the bottom of the frame. Again all we see is the jockey's cap.
Second Jockey | (Irish accent) Afternoon, Brian. (he shakes his head) No chance, no chance at all.
First Jockey | (nodding vigorously) No, no I think you're wrong there, Des, with the right kind of going, he's going to be in there at the finish, Des.
Second Jockey | (shaking vigorously) No chance, there's no chance.
Brian | Well in fact I can see last season's top jockey, Johnny Knowles. (two caps move over) Good afternoon, Johnny.
| Pause. Not even a cap is seen.
Third Jockey | (faintly) Hello Brian.
Brian | Er, could we have a box for Johnny please. (a cap comes into sight) Thank you.
Third Jockey | Hello Brian.
Brian | Thats better. Well there you are. Three well-known faces from the racing world. Thanks very much for coming along this afternoon, lads.
All | Not at all. (vigorous nodding of caps)
Brian | And the best wishes for the Derby.
All | Ah, thank you, Brian, Thanks very much. (they leave nodding)
Brian | Well in fact I hear they're ready for us now at the start of the main race this afternoon. So let's go right away and join Peter at the start.
| A view of the starting stalls, shot so we cannot see inside. CAPTION: '3.15 QUEEN VICTORIA HANDICAP'
Voice Over | Well they're under starter's orders for this very valuable Queen Victoria Handicap. And they're off, (the starting stall doors fly open; out come eight identically dressed Queen Victorias who go bustling off up the field) and Queen Victoria got a clean jump off, followed by Queen Victoria, Queen Victoria and Queen Victoria. It's Queen Victoria from Queen Victoria and Queen Victoria. It's Queen Victoria making the early running on the inside. And at the back Queen Victoria already a couple of lengths behind the leaders. Queen Victoria has now moved up to challenge Queen Victoria with Queen Victoria losing ground. Queen Victoria tucked in neatly on the stand side with a clear view. Queen Victoria still the back marker as they approach the halfway mark, but making ground now, suddenly past Queen Victoria with Queen Victoria, Queen Victoria and Queen Victoria still well placed as they approach the first fence. (a low angle shot as the Queen Victorias appear over the fence and thunder towards the camera) And at the first fence it's Queen Victoria just ahead of Queen Victoria and Queen Victoria falling away in third place. And Queen Victoria in the lead as they ...
| Cut back to the presenter in the studio; he is completely dressed as Queen Victoria, apart from his face.
Presenter | Well a very exciting race there at Epsom. And now over to the European Cup at Barcelona where the latest news is that Miguel Otana, the burly Real Madrid striker, was sent off for breaking wind in the forty-third minute. He'd already been cautioned for pursing his lips earlier on in the game and now he's off! So let's see a playback of that ... Brian.
| Cut to Brian, dressed the same way.
Brian | Yes ... er ... well as you can see ... there's Otana now (brief stock shot of football match) ... he gets the ... er ... through ball from Gomez (cut back to Brian) and er ... he makes no attempt to play the ball. He quite deliberately lets off! And to my mind he was within the box and the referee had no option whatsoever but to send him off.
| Cut to the presenter.
Presenter | Jimmy?
| We cut to the real Jimmy Hill dressed as Queen Victoria, veil, crown and all.
Jimmy Hill | Good evening.
Presenter | What do you make of that?
Jimmy Hill | Well the referees really are clamping down these days. Only last week the Belgian captain was sent off for having a Sony radio cassette player. And Gonerelli, the huge Italian defender, was sent off in Turin for having his sitting and dining room knocked through to form an open living area.
| Cut to the presenter.
Presenter | Hamlet?
| Cut to Hamlet.
Hamlet | Good evening.
| Cut quickly back to the presenter.
Presenter | Well you've got the girl on the bed and her legs up on the mantelpiece ...
| The nurse enters.
Nurse | Out, out, come on, come on, out ... (she hustles the presenter out of studio)
| Animated sketch. CAPTION: 'ACT FIVE - A HAM IN THE CASTLE' Mix to the theatre set we saw before. All the cast are dressed as Queen Victorias, except for Hamlet and Ophelia.
First Queen Victoria | Let four captains bear Hamlet like a soldier to the stage. For he was likely had he been put on to have proved most royally ...
| SUPERIMPOSED CAPTION: 'THE END'
| They come on and take bows. Superimposed Python credits in Shakespearean style and graphics.
| MONTY PYTHON BY WILLIAM SHAKESPEARE DRAMATIS PERSONAE HAMLET - TERRY JONES A BACHELOR FRIEND OF HAMLET'S GRAHAM CHAPMAN QUITE A BUTCH FRIEND OF HAMLET'S BUT STILL A BACHELOR TERRY GILLIAM A FRIEND OF HAMLET'S WHO, THOUGH MARRIED, STILL SEES HAMLET OCCASIONALLY MICHAEL PALIN A VERY CLOSE BACHELOR FRIEND OF HAMLET'S WHO, THOUGH ABOVE SUSPICION, DOES WEAR RATHER LOUD HIRTS ERIC IDLE ANOTHER PART OF THE DRAMATIS PERSONAE: A FRIEND OF HAMLET'S WHO LOVES BACHELORS - CAROL CLEVELAND A JIMMY HILL NEAR LONDON - JIMMY HILL A BACHELOR GENTLEMAN - BOB E. RAYMOND AN OPHELIA - CONSTANCE BOOTH A LOONY, BUT NOT A BACHELOR - SIR K. JOSEPH ADDITIONAL BLANK VERSE: J. CLEESE (NO RELATION)&NBSP;(OF HAMLET'S, THAT IS)> PERSONAE NON DRAMATIS BUT TECHNICALIS (SOME BACHELORS, SOME NOT) A MAKER-UPPER MAGGIE WESTON A COSTUME DESIGNER AND BACHELOR ANDREW ROSE A CAMERAMAN OF LONDON STAN SPEEL A SOUND RECORDIST OF ILL REPUTE JOHN BLIGHT AN EDITOR OF FILM WHO IS PARTLY BACHELOR AND PARTLY VEGETABLE WITH MINERAL CONNECTIONS BOB DEARBERG A STUDIO SOUND MAN MIKE JONES A LIGHTING SCOTSMAN JIMMY PURDIE A VISUAL EFFECTOR KEEN ON BACHELORS JOHN HORTON AN ASSISTANT PRODUCER FRIEND OF HAMLET'S BRIAN JONES A DESIGNED WHO PREFERS MARRIED MEN BUT KNOWS QUITE A FEW BACHELORS VALERIE WARRENDER A PROFESSIONAL PRODUCER AND AMATEUR BACHELOR IAN MACNAUGHTON A BACHELOR BROADCASTING CORPORATION BBC COLOUR.
| Fade out. Fade up on a moor. An explosion has just take place. Out of the smoke a ragged man walks towards the camera.
Man | And then...